hasPreviousChange property
bool
get
hasPreviousChange
Whether there is a previous change to navigate to.
Implementation
bool get hasPreviousChange => _currentChangeIndex > 0;
Whether there is a previous change to navigate to.
bool get hasPreviousChange => _currentChangeIndex > 0;