DiffIndexOutOfBoundsException class final
Thrown when a requested change index is out of bounds.
This typically occurs when FlutterDiffViewerController.goToChange is called with an index that does not exist in the current diff result.
- Inheritance
-
- Object
- DiffException
- DiffIndexOutOfBoundsException
Constructors
- DiffIndexOutOfBoundsException({required int requestedIndex, required int totalChanges})
-
const
Properties
- cause → Object?
-
Optional original error that caused this exception.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A human-readable description of the error.
finalinherited
- requestedIndex → int
-
The index that was requested.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalChanges → int
-
The total number of changes available.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited